Learn R Programming

PFIM (version 6.0)

EvaluateArm: Evaluate an arm.

Description

Evaluate an arm.

Usage

EvaluateArm(object, model, fim)

Value

The object fim containing the Fisher Information Matrix the two lists evaluationOutcomes, outcomesGradient containing the results of the evaluation of the outcome and the sensitivity indices.

Arguments

object

An object arm from the class Arm.

model

An object model from the class Model.

fim

An object fim from the class Fim.