EvaluateErrorModelDerivatives: Evaluate the error model derivatives.
Description
Evaluate the error model derivatives.
Usage
EvaluateErrorModelDerivatives(object, evaluationOutcome)
Value
A list giving the error variance and the Sigma derivatives.
Arguments
- object
An object from the class ModelError.
- evaluationOutcome
A list giving the results of the model evaluation.