EvaluateVarianceModel: Evaluate the variance of a model.
Description
Evaluate the variance of a model.
Usage
EvaluateVarianceModel(object, arm, evaluationModel)
Value
Return a list giving the results of the evaluation of the model variance.
Arguments
- object
An object from the class Model.
- arm
An object from the class Arm.
- evaluationModel
A list giving the outputs of the model evaluation.