Report: Generate optimization report

ReportR Documentation

Generate optimization report

Description

Generate optimization report

Report: generate the report.

Arguments

optimization

An Optimization object.

pfimproject

A object PFIMProject giving the Evaluation or Optimization.

outputPath

A string giving the path where the output are saved.

outputFile

A string giving the name of the output file.

plotOptions

A list giving the plot options.

Value

Generated report.

The html report of the design evaluation or optimization.


PFIM documentation built on Jan. 30, 2026, 5:08 p.m.