Generate the report for the evaluation
generateReportEvaluation(
object,
evaluationObject,
outputPath,
outputFile,
plotOptions
)Return the report for the evaluation in html.
An object from the class Fim.
A list giving the results of the evaluation of the model.
A string giving the output path.
A string giving the name of the output file.
A list giving the plot options.