Learn R Programming

PFIM (version 6.0)

getAdministrations: Get all the administration for an arm.

Description

Get all the administration for an arm.

Usage

getAdministrations(object)

Value

A list administrations of objects from the class Administration class giving the parameters of the administration for the object Arm.

Arguments

object

An object Arm from the class Arm.