getColumnAndParametersNamesFIM: Get the names of the names of the parameters associated to each column of the fim.
Description
Get the names of the names of the parameters associated to each column of the fim.
Usage
getColumnAndParametersNamesFIM(object, model)
Value
A list giving the names of the parameters associated to each column of the fim.
Arguments
- object
An object from the class Fim.
- model
An object from the class Model.