Learn R Programming

PFIM (version 6.0)

getColumnAndParametersNamesFIMInLatex: #' Get the names of the names of the parameters associated to each column of the fim in Latex format.

Description

#' Get the names of the names of the parameters associated to each column of the fim in Latex format.

Usage

getColumnAndParametersNamesFIMInLatex(object, model)

Value

A list giving the names of the parameters associated to each column of the fim in Latex format.

Arguments

object

An object from the class Fim.

model

An object from the class Model.