getConditionNumberVarianceEffects: Get the condition number of the matrix of the variance effects.
Description
Get the condition number of the matrix of the variance effects.
Usage
getConditionNumberVarianceEffects(object)
Value
A numeric giving the condition number of the matrix of the variance effects.
Arguments
- object
An object from the class Fim..