Learn R Programming

PFIM (version 6.0)

getInitialConditions: Get the initial condition for the evaluation of an ode model.

Description

Get the initial condition for the evaluation of an ode model.

Usage

getInitialConditions(object)

Value

The list initialConditions for the object Arm.

Arguments

object

An object Arm from the class Arm.