Learn R Programming

PFIM (version 6.0)

getOutcomesEvaluation: Get the results of the evaluation of the outcomes.

Description

Get the results of the evaluation of the outcomes.

Usage

getOutcomesEvaluation(object)

Value

The list outcomesEvaluation containing the results of the design evaluation for the outcomes.

Arguments

object

An object Design from the class Design.