Learn R Programming

PFIM (version 6.0)

getOutcomesGradient: Get the results of the evaluation of the outcome gradients.

Description

Get the results of the evaluation of the outcome gradients.

Usage

getOutcomesGradient(object)

Value

The list outcomesGradient containing the results of the design evaluation for the outcome gradients.

Arguments

object

An object Design from the class Design.