Learn R Programming

PFIM (version 6.0)

getSamplingTimes: Get the vectors of sampling times for an arm.

Description

Get the vectors of sampling times for an arm.

Usage

getSamplingTimes(object)

Value

The list samplingTimes for the object Arm.

Arguments

object

An object Arm from the class Arm.