Learn R Programming

PFIM (version 6.0)

plotWeights: Graph of the weights for the multiplicative algorithm.

Description

Graph of the weights for the multiplicative algorithm.

Usage

plotWeights(object, threshold)

Value

The graphs of the weights for the multiplicative algorithm.

Arguments

object

An object from the class OptimizationAlgorithm.

threshold

A numeric giving the threshold for the optimal weights in the multiplicative algorithm.