reportTablesFIM: Generate the tables for the report.
Description
Generate the tables for the report.
Usage
reportTablesFIM(object, evaluationObject)
Value
A list giving the table in kable format for the report.
Arguments
- object
An object from the class Fim.
- evaluationObject
A list giving the results of the evaluation of the model.