Learn R Programming

PFIM (version 6.0)

reportTablesModelError: Generate the tables for model errors for the evaluation report.

Description

Generate the tables for model errors for the evaluation report.

Usage

reportTablesModelError(object)

Value

A kable table for the evaluation report.

Arguments

object

An object from the class Model.