Learn R Programming

PFIM (version 6.0)

reportTablesModelParameters: Generate the tables for model parameters for the evaluation report.

Description

Generate the tables for model parameters for the evaluation report.

Usage

reportTablesModelParameters(object)

Value

A kable table for the evaluation report.

Arguments

object

An object from the class Model.