resizeFisherMatrix: Resize the fisher Matrix from a vector to a matrix.
Description
Resize the fisher Matrix from a vector to a matrix.
Usage
resizeFisherMatrix(nbOfDimensions, fisherMatrix)
Value
The Fisher matrix of size nbOfDimensions*nbOfDimensions
Arguments
- nbOfDimensions
: a numeric for the dimensions of the fisher matrix.
- fisherMatrix
: a vector that contain the low triangular Fisher matrix + its main diagonal.