Learn R Programming

PFIM (version 6.0)

setAdministrations: Set all the administration for an arm.

Description

Set all the administration for an arm.

Usage

setAdministrations(object, administrations)

Value

The object Arm with the list administrations of objects from the class Administration class giving the parameters of the administration for the object Arm.

Arguments

object

An object Arm from the class Arm.

administrations

A list administrations of objects from the class Administration class giving the parameters of the administration for the object Arm.