setEvaluationInitialDesignResults: Set the evaluation results of the initial design.
Description
Set the evaluation results of the initial design.
Usage
setEvaluationInitialDesignResults(object, value)
Value
The object with the updated object from the class Evaluation.
Arguments
- object
An object from the class Optimization.
- value
An object from the class Evaluation giving the evaluation results of the initial design.