Learn R Programming

PFIM (version 6.0)

setInitialConditions: Set the initial condition for the evaluation of an ode model.

Description

Set the initial condition for the evaluation of an ode model.

Set the initial conditions of a ode model.

Usage

setInitialConditions(object, initialConditions)

setInitialConditions(object, initialConditions)

Value

An object Arm from the class Arm with the new initial conditions initialConditions.

The model with the updated initial conditions.

Arguments

object

An object from the class Model.

initialConditions

A list giving the initial conditions.