setIterationAndCriteria: Set the iteration with the convergence criteria.
Description
Set the iteration with the convergence criteria.
Usage
setIterationAndCriteria(object, value)
Value
A dataframe giving the iteration with the convergence criteria.
Arguments
- object
An object from the class OptimizationAlgorithm.
- value
A dataframe giving the iteration with the convergence criteria.