Learn R Programming

PFIM (version 6.0)

setMu: Set the value of the fixed effect mu of an object.

Description

Set the value of the fixed effect mu of an object.

Usage

setMu(object, value)

Value

The object with the updated fixed effect mu.

Arguments

object

An object defined form a class of PFIM.

value

The value of the fixed effect mu.