Learn R Programming

PFIM (version 6.0)

setOdeSolverParameters: Set the parameters of the ode solver.

Description

Set the parameters of the ode solver.

Usage

setOdeSolverParameters(object, odeSolverParameters)

Value

The model with the updated parameters of the ode solver.

Arguments

object

An object from the class Model.

odeSolverParameters

A list giving the parameters of the ode solver.