setOutcomesForEvaluation: Set the outcomes of a model used for the evaluation (is scales outcomes).
Description
Set the outcomes of a model used for the evaluation (is scales outcomes).
Usage
setOutcomesForEvaluation(object, outcomes)
Value
The model with the updated outcomes for the evaluation.
Arguments
- object
An object from the class Model.
- outcomes
A list giving the outcomes of a model used for the evaluation (is scales outcomes).