Learn R Programming

PFIM (version 6.0)

setOutcomesGradient: Set the results of the evaluation of the outcomes.

Description

Set the results of the evaluation of the outcomes.

Usage

setOutcomesGradient(object, outcomesGradient)

Value

An object Design with the list outcomesGradient updated.

Arguments

object

An object Design from the class Design.

outcomesGradient

A list containing the evaluation of the outcome gradients.