Learn R Programming

PFIM (version 6.0)

setSamplingTimes: Set the vectors of sampling times for an arm.

Description

Set the vectors of sampling times for an arm.

Usage

setSamplingTimes(object, samplingTimes)

Value

An object Arm from the class Arm with the new sampling times samplingTimes.

Arguments

object

An object Arm from the class Arm.

samplingTimes

The list containing the new sampling times.