| Report | R Documentation |
Generate optimization report
Report: generate the report.
optimization |
An |
pfimproject |
A object |
outputPath |
A string giving the path where the output are saved. |
outputFile |
A string giving the name of the output file. |
plotOptions |
A list giving the plot options. |
Generated report.
The html report of the design evaluation or optimization.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.