#' Get the names of the names of the parameters associated to each column of the fim in Latex format.
getColumnAndParametersNamesFIMInLatex(object, model)A list giving the names of the parameters associated to each column of the fim in Latex format.
An object from the class Fim.
An object from the class Model.