getOdeSolverParameters: Get the parameters for the ode solvers of an object.
Description
Get the parameters for the ode solvers of an object.
Usage
getOdeSolverParameters(object)
Value
The list giving the parameters for the ode solvers.
Arguments
- object
An object defined form a class of PFIM.