Set all the administration for an arm.
setAdministrations(object, administrations)The object Arm with the list administrations of objects from the class Administration class giving
the parameters of the administration for the object Arm.
An object Arm from the class Arm.
A list administrations of objects from the class Administration class giving
the parameters of the administration for the object Arm.