Set the initial condition for the evaluation of an ode model.
Set the initial conditions of a ode model.
setInitialConditions(object, initialConditions)setInitialConditions(object, initialConditions)
An object Arm from the class Arm with the new initial conditions initialConditions.
The model with the updated initial conditions.
An object from the class Model.
A list giving the initial conditions.