setSamplingConstraintForOptimization: Set the sampling times constraint for optimization with PSO, PGBO and Simplex
Description
Set the sampling times constraint for optimization with PSO, PGBO and Simplex
Usage
setSamplingConstraintForOptimization(object)
Value
The arms with the sampling times constraints.
Arguments
- object
An object from the class Design.